@@ -3,6 +3,7 @@
 
 from .cache_annotator import CacheAnnotator
 from .annotator import Annotator
+from .annotator_novel_fams import AnnotatorNovelFams
 
 ##
 def get_cache_annotator(args):
@@ -20,4 +21,12 @@ def get_annotator(args, annot, excel, report_orthologs):
     
     return annotator
 
+##
+def get_annotator_novel_fams(args, annot, excel, report_orthologs):
+    annotator = None
+
+    annotator = AnnotatorNovelFams(args, annot, excel, report_orthologs)
+    
+    return annotator
+
 ## END
